@@ -8,6 +8,17 @@ class Entity(object):
     """
 
     def __init__(self, _id, _data=None, api=None, update_threshold=30):
+        """Base entity initialization
+
+        Args:
+            _id (str): Entity ID.
+            _data (dict): Entity's data.
+            api (APIHandler): API object for performing requests.
+            update_threshold (int): Update threshold to auto-update data when accessing _data
+                object. By default is 30, which means that data retrieved by the object won't
+                be older than 30 secs. If set to None, then auto-update functionality is disabled,
+                returning always the same data when the object was created.
+        """
         self._id = _id
         self._data = _data
         self._last_updated = None
@@ -27,6 +38,8 @@ class Entity(object):
         raise NotImplementedError()
 
     def should_update(self):
+        if self._update_threshold is None:
+            return False
         return (
             self._last_updated is None or
             time.time() - self._last_updated > self._update_threshold
